/*
 * Copyright 2008, by Danil S. Trommel, Avance, The Netherlands
 * 
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

using System;
using System.Xml;
using System.Collections.Generic;

using miniTeach.IO.FileParser;


namespace miniTeach.IO
{
	/// <summary>
	/// Factory that produces a FileParser object based on the interface IFileParser.
	/// </summary>
	public static class FileParserFactory
	{
		/// <summary>
		/// Creation of the correct Teach fileparser
		/// </summary>
		/// <returns>the valid fileparser for the given Teach version</returns>
		public static IFileParser CreateFileParser(string version)
		{
			//Convert version string to integer object (easier to filter older versions etc.)
			int intVersion = Convert.ToInt32(version);
			
			//Start with highest version and work backwards
			if (intVersion >= 820)
			{
				return new Version820FileParser();
			}
			else if (intVersion >= 817)
			{
				return new Version817FileParser();
			}
			else if (intVersion >= 815)		//all other versions?
			{
				return new Version815FileParser();
			}
			else
			{
				throw new Exception("CreateFileParser() Error; Unknown or unsupported fileformat");
			}
		}
		
	}
}
