/*
 * Copyright 2008, by Danil S. Trommel, Avance, The Netherlands
 * 
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

using System;
using System.Xml;
using System.Collections.Generic;

using miniTeach.Teach;
using miniTeach.Tools;

namespace miniTeach.IO.FileParser
{
	public class Version820FileParser : IFileParser
	{

		public Question ParseXML(XmlNode nodeItem)
		{
			//Determine the type
			QuestionType questionType = (QuestionType)Convert.ToByte(nodeItem.SelectSingleNode("answers").Attributes.GetNamedItem("type").Value);
			//Create new Question, based on the above type
			Question newQuestion = QuestionFactory.CreateQuestion(questionType);

			
			//1. Questions (+ boolean values for rich text formatting)
			bool[] usesRichFormatting = new bool[0];
			newQuestion.Questions = XMLTools.GetXMLStringsWithBooleanAttributes(nodeItem.SelectNodes("questions/question"),
			                                                                    ref usesRichFormatting, "rich");
			newQuestion.QuestionUsesRichFormatting = usesRichFormatting;
			
			//2. Answers (depending on type)
			if (questionType == QuestionType.Normal)
			{
				newQuestion.Answers = XMLTools.GetXMLStrings(nodeItem.SelectNodes("answers/answer"));
				newQuestion.AnswerUsesRichFormatting = new bool[newQuestion.Answers.Length];	//will default to false
			}
			else if (questionType == QuestionType.MultipleChoiceSingleAnswer||
			         questionType == QuestionType.MultipleChoiceMultipleAnswers)
			{
				bool[] multipleChoiceAnswers = new bool[0];
				newQuestion.Answers = XMLTools.GetXMLStringsWithBooleanAttributes(nodeItem.SelectNodes("answers/answer"),
				                                                                  ref multipleChoiceAnswers, "ok");
				((MultipleChoiceQuestion)newQuestion).MultipleChoiceAnswers = multipleChoiceAnswers;
				newQuestion.AnswerUsesRichFormatting = new bool[newQuestion.Answers.Length];	//not in use; default to false
			}
			
			//3. Remarks (might not be used at all!)
			try
			{
				newQuestion.Remarks = nodeItem.SelectSingleNode("remarks").InnerText;
				newQuestion.RemarkUsesRichFormatting = new bool[]{false};	//not in use; default to false
			}
			catch {}	//TODO: replace try-catch with a more diplomatic solution; test existence of the node "remark"
			
			return newQuestion;
		}
		
	}
}
