/*
 * Copyright 2008, by Danil S. Trommel, Avance, The Netherlands
 * 
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

using System;
using System.Xml;
using System.Collections.Generic;

using miniTeach.IO.FileParser;
using miniTeach.Teach;


namespace miniTeach.IO
{
	public static class FileService
	{
		
		public static Question[] LoadAndParseTeachFile(string filePath)
		{
			try
			{				
				XmlDocument xmldocument = new XmlDocument();	//Create the XML Document
				xmldocument.Load(filePath);						//Load the Xml file
				
				//Determine the version
				string version = (xmldocument.SelectSingleNode("/teach2000/version")).InnerText;
				IFileParser fileParser = FileParserFactory.CreateFileParser(version);
				
				//Create a list to store the questions
				List<Question> questionlist = new List<Question>();
				//Get the list with items (each containing a question with answers, scores etc)
				XmlNodeList xmlnodelist = xmldocument.SelectNodes("/teach2000/message_data/items/item");
				
				//Iterate through the nodelist
				foreach (XmlNode xmlnode in xmlnodelist) 
				{
					questionlist.Add( fileParser.ParseXML(xmlnode) );
				}
				
				return questionlist.ToArray();
			}
			catch (Exception ex)
			{
				throw new Exception("LoadTeachFile() Error: " + ex.Message);
			}
		}
				
	}
}
