﻿/*
 * Copyright 2008, by Daniël S. Trommel, Avancée, The Netherlands
 * 
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

using System;
using System.Drawing;
using System.Windows.Forms;

using miniTeach.Settings;
using miniTeach.Teach;

namespace miniTeach
{
	public partial class MainForm : Form
	{
		
		private TeachExam Exam;
		
		public void RestartExam()
		{
			Exam.Restart(TeachSettings.Instance.ExamSettings);
			NextQuestion();
			
			InitInfo();
			UpdateProgress();
		}
		
		private void NextQuestion()
		{
			if (Exam.ExamFinished())
			{
				UpdateUIForFase();
				m_TeachPictureBox.ShowFase(Exam.Fase);
			}
			else
			{
				Question question = Exam.GetNextQuestion();
				m_TeachPictureBox.NewQuestion(question, Exam.Settings.Direction);
				UpdateUIForQuestion(question.QuestionType);
			}
		}
		
		private void RecordResult(bool result)
		{
			Exam.QuestionCorrectlyAnswered(result);
			UpdateGrade();
			UpdateIcon();
			UpdateProgress();
		}
		
		private void UpdateGrade()
		{
			double grade = Exam.CalculateGrade();
			lGrade.Text = String.Format("{0:0.0}", grade);
			
			if (grade < 5.5d)
			{
				lGrade.ForeColor = Color.Red;
			}
			else
			{
				lGrade.ForeColor = Color.Green;
			}
		}
		
		private void UpdateProgress()
		{
			lProgress.Text = Exam.GetProgressString();
		}
		
		private void CheckAnswer()
		{
			if (Exam.Fase == ExamFase.ShowingQuestion)	//Showing question, proceed to check the answer inputted.
			{
				Exam.Fase = ExamFase.ShowingAnswer;				//update fase
				m_TeachPictureBox.CheckAnswer(tbAnswer.Text);	//check user input
				UpdateUIForFase();
			}
			else if (Exam.Fase == ExamFase.ShowingAnswer)	//Showing answer, proceed to next question
			{
				RecordResult(m_TeachPictureBox.QuestionCorrectlyAnswered); 	//first pass the result
				NextQuestion();
			}
			else if (Exam.Fase == ExamFase.AskingRestart)
			{
				RestartExam();
			}
		}
		
		private void ForceAnswer(bool result)
		{
			//User forced the correctness of his/her answer
			if (Exam.Fase == ExamFase.ShowingAnswer)
			{
				RecordResult(true);
				NextQuestion();
			}
		}
		
		

		
	}
}
