/*
 * Copyright 2008, by Danil S. Trommel, Avance, The Netherlands
 * 
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

using System;
using System.Drawing;
using System.Windows.Forms;

using miniTeach.Settings;
using miniTeach.Tools;
using miniTeach.Teach;
using miniTeach.UI;

namespace miniTeach
{

	public partial class MainForm : Form
	{

		
		#region Unsorted
		
		public void OnSIPEnabledChange(object sender, System.EventArgs e)
		{
			ResizeUI();	//Resize UI whenever onscreen keybord is enabled or disabled
		}

		private void tbAnswer_GotFocus(object sender, System.EventArgs e)
		{
			SIPTool.DisableCompletion(tbAnswer);
		}
		
		public void SetLoadingProgress(string t)
		{
			this.m_Splash.lProgress.Text = t;
			if (this.m_Splash.myProgressBar.Value < this.m_Splash.myProgressBar.Maximum)
			{
				this.m_Splash.myProgressBar.Value += 1;
			}
			
			Application.DoEvents();	//Force execution of msg-queue
		}
		
		private void tbAnswer_KeyPress(object sender, System.Windows.Forms.KeyPressEventArgs e)
		{
			if (e.KeyChar == (char)Keys.Enter)
			{
				CheckAnswer();
			}
		}
		
		private void bCheck_Click(object sender, System.EventArgs e)
		{
			CheckAnswer();
		}
		
		private void bForceCorrectAnswer_Click(object sender, System.EventArgs e)
		{
			ForceAnswer(true);
		}
		
		private void bFout_Click(object sender, System.EventArgs e)
		{
			myTimer.Enabled = false;
			paInputFlash.Visible = false;
			ForceAnswer(false);
		}
		
		private void bGoed_Click(object sender, System.EventArgs e)
		{
			myTimer.Enabled = false;
			paInputFlash.Visible = false;
			ForceAnswer(true);
		}
		
		#endregion

		
		#region Timer
		
		private int m_FlashWaitMilliSeconds;	//Need to store it separately, cannot use TeachSettings as it could be changed whilst running a FlashCard
		private const int updateInterval = 500;
		
		public void StartFlashTimer()
		{
			m_FlashWaitMilliSeconds = TeachSettings.Instance.FlashTime;
			ShowProgress(m_FlashWaitMilliSeconds / updateInterval);
			myTimer.Interval = updateInterval;
			myTimer.Enabled = true;
		}
		
		public void ShowProgress(int totalCount)
		{
			pbrProgress.Minimum = 0;
			pbrProgress.Maximum = totalCount;
			pbrProgress.Value = 0;
			pbrProgress.Visible = true;
		}
		
		public void myTimer_Tick(object sender, System.EventArgs e)
		{
			if (pbrProgress.Value >= pbrProgress.Maximum)
			{
				myTimer.Enabled = false;
				pbrProgress.Visible = false;
				CheckAnswer();
				paInputFlash.Visible = true;
			}
			else
			{
				pbrProgress.Value += 1;
			}
		}
		
		#endregion

		
	}
}
