/*
 * Copyright 2008, by Danil S. Trommel, Avance, The Netherlands
 * 
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

using System;
using System.Drawing;
using System.Windows.Forms;

using miniTeach.Settings;
using miniTeach.Tools;
using miniTeach.Teach;
using miniTeach.UI;

namespace miniTeach
{

	//TODO: clean-up, group controls and add comments
	
	public partial class MainForm : Form
	{
		private static string[] checkButtonText = new string[]{"?", ">", "|<<"};
		
		public void InitUI()
		{
			bCheck = new Button();
			bCheck.Text = "?";
			bCheck.BackColor = Color.LightBlue;
			bCheck.Click += bCheck_Click;
			
			bForceCorrectAnswer = new Button();
			bForceCorrectAnswer.Text = "Goedrekenen!";
			bForceCorrectAnswer.BackColor = Color.LightGreen;
			bForceCorrectAnswer.Click += bForceCorrectAnswer_Click;
			
			paInputFlash = new Panel();
			bFout = new Button();
			bFout.Text = "Nope...";
			bFout.BackColor = Color.LightSalmon;
			bFout.Click += bFout_Click;
			
			bGoed = new Button();
			bGoed.Text = "Yes !";
			bGoed.BackColor = Color.LightGreen;
			bGoed.Click += bGoed_Click;
			
			lProgress = new Label();
			lProgress.Text = "Open File...";
			lGrade = new Label();
			lGrade.TextAlign = ContentAlignment.TopRight;
			
			m_IconPictureBox = new PictureBox();
			m_TeachPictureBox = new TeachPictureBox();
			
			tbAnswer = new TextBox();
			tbAnswer.KeyPress += tbAnswer_KeyPress;	//subscribe to keypress-event
			pbrProgress = new ProgressBar();
			
			if (TeachSettings.Instance.IsWinCE)
			{
				//Subscribe to focus-event; used to prevent text-completion (!)
				tbAnswer.GotFocus += this.tbAnswer_GotFocus;
			}
			
			myTimer = new Timer();
			myTimer.Tick += myTimer_Tick;
			
			paInfo = new Panel();
			paInfo.BackColor = Color.White;
			paQuestion = new Panel();
			paQuestion.BackColor = Color.White;
			paInput = new Panel();
			paInput.BackColor = Color.White;

			paInfo.Controls.Add(lProgress);
			paInfo.Controls.Add(lGrade);
			paInfo.Controls.Add(m_IconPictureBox);
			paInfo.Controls.Add(bForceCorrectAnswer);
			
			paQuestion.AutoScroll = true;
			paQuestion.Controls.Add(m_TeachPictureBox);
			m_TeachPictureBox.Location = new Point(TeachSettings.TextOffset, TeachSettings.TextOffset + 1);
			
			bForceCorrectAnswer.BringToFront();
			bForceCorrectAnswer.Visible = false;

			paInput.Controls.Add(tbAnswer);
			paInput.Controls.Add(bCheck);
			paInputFlash.Controls.Add(bFout);
			paInputFlash.Controls.Add(bGoed);

			pbrProgress.Visible = false;
			paInput.Visible = false;
			paInputFlash.Visible = false;

			this.Controls.Add(paInfo);
			this.Controls.Add(paQuestion);
			//this.Controls.Add(paRemark);
			this.Controls.Add(paInput);
			this.Controls.Add(paInputFlash);
			this.Controls.Add(pbrProgress);
		}

		public void UpdateFontsize()
		{
			FontMetricTool.SetFontSize(TeachSettings.Instance.FontSize);
			FontMetricTool.UpdatePixelFontSize();

			//Update fonts on controls
			Font font = new Font(TeachSettings.FontName, TeachSettings.Instance.EmTextHeight, FontStyle.Regular);
			bCheck.Font = font;
			bForceCorrectAnswer.Font = font;
			lProgress.Font = font;
			lGrade.Font = font;
			tbAnswer.Font = font;
			
			m_TeachPictureBox.InitFont();	//update the pre-initialized font-objects
			ResizeUI();
			
			if (Exam != null)
			{
				m_TeachPictureBox.ShowFase(Exam.Fase);	//Repaint the question
			}
		}

		public void ResizeUI(object sender, System.EventArgs e)
		{
			ResizeUI();
		}
		
		public void ResizeUI()
		{
			try {
				//Bounds of WorkingArea
				int scrWidth = Screen.PrimaryScreen.WorkingArea.Width;
				int scrHeight = Screen.PrimaryScreen.WorkingArea.Height;

				if (TeachSettings.Instance.IsWinCE)
				{
					//WinCE (WM2003 etc)
					scrHeight = m_SIP.VisibleDesktop.Height + 1;
					if (!m_SIP.Enabled)
					{
						//Als onscreen keyboard (SIP) niet wordt gebruikt,
						//klopt de hoogte niet:: Menu-hoogte moet er ook nog af!
						scrHeight -= System.Windows.Forms.SystemInformation.MenuHeight;
					}
				}
				else
				{
					//Win32 (XP etc)
					scrWidth = this.ClientSize.Width;
					//Me.Width-8
					scrHeight = this.ClientSize.Height;
					//Me.Height-54
				}

				int ScoreWidth = (int)(6 * TeachSettings.Instance.FontPixelDimensions.AverageCharWidth);
				int IconWidth = 26;
				int IconHeight = IconWidth;
				int ProgresWidth = Math.Max(50, scrWidth - ScoreWidth - IconWidth - TeachSettings.TextOffset - 1);
				int CheckWidth = 40;
				int InfoHeight = (int)Math.Max(IconHeight + 2, TeachSettings.Instance.FontPixelDimensions.LineHeight);
				int InputHeight = (int)Math.Max(IconHeight, TeachSettings.Instance.FontPixelDimensions.LineHeight);
				int RemarkHeight = InputHeight + 1;
				int InfoHeightRest = Convert.ToInt32(Math.Floor((InfoHeight - TeachSettings.Instance.FontPixelDimensions.LineHeight)));
				
				//[1] Info Panel
				paInfo.Location = new Point(0, 0);
				paInfo.Size = new Size(scrWidth, InfoHeight);
				//[1a] Progress
				lProgress.Size = new Size(ProgresWidth, InfoHeight);
				lProgress.Location = new Point(TeachSettings.TextOffset, 1 + InfoHeightRest / 2);
				//[1b] Score Label
				lGrade.Size = new Size(ScoreWidth, InfoHeight);
				lGrade.Location = new Point(paInfo.Width - IconWidth - lGrade.Width - 10, 1 + InfoHeightRest / 2);
				//[1c] Smiley PictureBox
				m_IconPictureBox.Size = new Size(IconWidth, IconWidth);
				m_IconPictureBox.Location = new Point(Math.Max(0, paInfo.Width - IconWidth - 2), 1 + Convert.ToInt32(Math.Floor((InfoHeight - IconHeight) / 2)));

				//[2] Input Panel
				tbAnswer.Size = new Size(scrWidth - CheckWidth, InputHeight);
				tbAnswer.Location = new Point(0, 0);
				bCheck.Size = new Size(CheckWidth, tbAnswer.Height);
				bCheck.Location = new Point(scrWidth - CheckWidth, 0);
				bForceCorrectAnswer.Size = new Size(Math.Min(scrWidth, 100), tbAnswer.Height);
				bForceCorrectAnswer.Location = new Point((paInfo.Width-bForceCorrectAnswer.Width)/2, (paInfo.Height-bForceCorrectAnswer.Height)/2);
				paInput.Size = new Size(scrWidth, tbAnswer.Height);
				paInput.Location = new Point(0, scrHeight - paInput.Height);

				//[2b] Flash Input Panel
				bFout.Location = new Point(0, 0);
				bFout.Size = new Size(paInput.Width / 2, paInput.Height);
				bGoed.Location = new Point(paInput.Width / 2, 0);
				bGoed.Size = new Size(paInput.Width / 2, paInput.Height);
				paInputFlash.Size = paInput.Size;
				paInputFlash.Location = paInput.Location;

				//[2c] Progressbar
				pbrProgress.Size = paInput.Size;
				pbrProgress.Location = paInput.Location;

				//[3] Question Panel
				paQuestion.Size = new Size(scrWidth, paInput.Top - paInfo.Bottom); //paRemark.Top - paInfo.Bottom);
				paQuestion.Location = new Point(0, paInfo.Bottom);
			}

			catch (Exception ex) {
				LogTool.WriteToLog(ex.ToString());
			}

		}
		
		private void UpdateIcon()
		{
			int s = (int)Math.Ceiling(Exam.CalculateGrade());
			
			//Last answer correct? Use the green icons (= red index + 10)
			if (Exam.LastAnswerCorrect)
			{
				s += 10;
			}
			
			Bitmap img = ResourceTool.GetBitmap(s.ToString());
			m_IconPictureBox.Image = img;
		}

		private void UpdateUIForFase()
		{
			bForceCorrectAnswer.Visible = (Exam.Fase == ExamFase.ShowingAnswer && Exam.Settings.Method != ExamMethod.Flash);
			tbAnswer.Enabled = (Exam.Fase == ExamFase.ShowingQuestion);
			bCheck.Text = checkButtonText[(int)Exam.Fase];
			
			ColorAnswerTextBox();
			tbAnswer.Focus();
		}
		
		private void InitInfo()
		{
			lGrade.Text = "";
			if (m_IconPictureBox.Image != null)
			{
				m_IconPictureBox.Image = new Bitmap(1,1);
			}
		}
		
		private void ColorAnswerTextBox()
		{
			if (Exam.Fase == ExamFase.ShowingAnswer)
			{
				if (m_TeachPictureBox.QuestionCorrectlyAnswered)
				{
					tbAnswer.BackColor = Color.LightGreen;
				}
				else
				{
					tbAnswer.BackColor = Color.OrangeRed;
				}
			}
			else
			{
				tbAnswer.BackColor = Color.White;
			}
		}

		private void UpdateUIForQuestion(QuestionType questionType)
		{
			UpdateUIForFase();
			
			//Controls
			bForceCorrectAnswer.Visible = false;
			if (questionType == QuestionType.Normal)
			{
				if (Exam.Settings.Method == ExamMethod.Flash)
				{
					UpdateInputControls(false, false, "");
					StartFlashTimer();
				}
				else
				{
					UpdateInputControls(true, true, "");
				}
			}
			else if (questionType == QuestionType.MultipleChoiceSingleAnswer ||
			         questionType == QuestionType.MultipleChoiceMultipleAnswers)
			{
				UpdateInputControls(true, false, "Select the correct answer(s)");
			}
			
			paInputFlash.Visible = false;
		}
		
		private void UpdateInputControls(bool enableCheck, bool enableAnswer, string answerText)
		{
			bCheck.Enabled = enableCheck;
			tbAnswer.Enabled = enableAnswer;
			tbAnswer.Text = answerText;
			paInput.Visible = (enableCheck || enableAnswer);
		}
		
		
	}
}
