/*
 * Copyright 2008, by Danil S. Trommel, Avance, The Netherlands
 * 
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program. If not, see <http://www.gnu.org/licenses/>.
*/


#define DEBUG	//Used to detect debug mode

using System;
using System.Collections.Generic;
using System.Drawing;
using System.Windows.Forms;

using miniTeach.UI;
using miniTeach.Settings;
using miniTeach.Tools;

namespace miniTeach
{
	/// <summary>
	/// Description of MainForm.
	/// </summary>
	public partial class MainForm : Form
	{
		
		private void InitializeSettingsEtc()
		{
			//TODO: move to TeachSettings constructor?
			//Application Path
			TeachSettings.Instance.ApplicationPath = SystemTool.GetCurrentApplicationPath();
			//Determine platform (WinCE or not)
			TeachSettings.Instance.IsWinCE = (System.Environment.OSVersion.Platform == PlatformID.WinCE);
			
			LogTool.CleanLog();
			TeachSettings.Instance.LoadSettings("\\settings.xml");
			
			//Lowerbound on the fontsize
			if (TeachSettings.Instance.FontSize < 8)
			{
				TeachSettings.Instance.FontSize = 8;
			}
			FontMetricTool.SetFontSize(TeachSettings.Instance.FontSize);
			
			//create and display the splash screen form
			//and make the main form it's owner
			this.m_Splash = new SplashForm();
			this.m_Splash.Owner = this;
			this.m_Splash.Show();
			Application.DoEvents();

			//disable the main form
			//to avoid the title bar
			//being drawn over the splash screen
			//during initialization
			this.Enabled = false;
		}
		
		private void LoadUI()
		{
			this.Text = TeachSettings.VersionInfo;

			Application.DoEvents();

			try 
			{
				SetLoadingProgress("Loading Menu");
				InitMenu();
				
				SetLoadingProgress("Loading Metrics");			
				FontMetricTool.InitMetrics();	//Calculate the metrics (platform-dependent)				
				FontMetricTool.UpdatePixelFontSize();	//Calculate the pixel-sizes:
			}
			catch (Exception ex) 
			{
				LogTool.WriteToLog(ex.ToString());
				this.Close();
				return;
			}

			if (TeachSettings.Instance.IsWinCE)
			{
				m_SIP = new Microsoft.WindowsCE.Forms.InputPanel();
				m_SIP.EnabledChanged += OnSIPEnabledChange;
			}

			SetLoadingProgress("Loading UI");
			InitUI();
			UpdateFontsize();
			ResizeUI();
			UpdateMenuCheck();
			
			SetLoadingProgress("Finished loading!");

			//Re-Enable the form
			//me.WindowState = WindowState.Maximized
			this.Enabled = true;
			this.Visible = true;

			//close the splash screen and dispose
			this.m_Splash.Close();
			this.m_Splash.Dispose();
			this.m_Splash = null;
			
			//Delegate resize events
			this.Resize += ResizeUI;
			
			#if DEBUG
				//Debug mode; open standard teachfile, since using OpenFileDialog
				//to open a list will throw an error (STA)!
				LoadFile(TeachSettings.Instance.ApplicationPath + "\\list\\test820.t2k");
			#endif
			
		}
		
		private void MyForm_Closing(object sender, System.ComponentModel.CancelEventArgs e)
		{
			//Save settings
			TeachSettings.Instance.SaveSettings();
			GC.Collect();
		}
		
		public void ExitProgram(object sender, System.EventArgs e)
		{
			if (MessageBox.Show("Programma verlaten?") == DialogResult.OK)
			{
				this.Close();
			}
		}

	}
}

