/*
 * Copyright 2008, by Danil S. Trommel, Avance, The Netherlands
 * 
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

using System;
using System.Xml;
using System.Collections.Generic;

namespace miniTeach.Teach
{
	public class MultipleChoiceQuestion : Question
	{
		//Additional fields for the multiplechoice-type;
		//a bool-array to store the correct options
		private bool[] m_MultipleChoiceAnswers;
		public bool[] MultipleChoiceAnswers {
			get { return m_MultipleChoiceAnswers; }
			set { m_MultipleChoiceAnswers = value; }
		}
		
		public MultipleChoiceQuestion(QuestionType questionType)
		{
			base.QuestionType = questionType;
		}
		
		public override bool IsAnswerCorrect(string inputText)
		{
			//This function is required by the design pattern of Question
			//If called, throw an error; parent code should do the right call!
			throw new Exception("IsAnswerCorrect() Error: this question is multiplechoice");
		}
		
		public override bool IsAnswerCorrect(bool[] tickedBoxes)
		{
			if (tickedBoxes.Length == m_MultipleChoiceAnswers.Length)	//check length
			{
				for (int index = 0; index < tickedBoxes.Length; index++)
				{
					if (tickedBoxes[index] != m_MultipleChoiceAnswers[index])
					{
						return false;	//found a non-corresponding value!
					}
				}
			}
			else
			{
				//Error in parent (calling) code!
				throw new Exception("IsAnswerCorrect() Error: the number of ticked boxes do not correspond to the number of choices possible!");
			}
			
			return true;
		}
		
	}
}
