/*
 * Copyright 2008, by Danil S. Trommel, Avance, The Netherlands
 * 
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

using System;
using System.Xml;
using System.Collections.Generic;

namespace miniTeach.Teach
{
	/// <summary>
	/// Abstract class that contains the base fields and forces
	/// child classes to implement the IsAnswerCorrect functions.
	/// </summary>
	public abstract class Question
	{
		
		#region Static fields

		private QuestionType m_QuestionType;
		public QuestionType QuestionType {
			get { return m_QuestionType; }
			set { m_QuestionType = value; }
		}
		
		private string[] m_Questions;
		public string[] Questions {
			get { return m_Questions; }
			set { m_Questions = value; }
		}
		
		private bool[] m_QuestionUsesRichFormatting;
		public bool[] QuestionUsesRichFormatting {
			get { return m_QuestionUsesRichFormatting; }
			set { m_QuestionUsesRichFormatting = value; }
		}
		
		private string[] m_Answers;
		public string[] Answers {
			get { return m_Answers; }
			set { m_Answers = value; }
		}
		
		//N.B.: not yet used in any version, but is included for future uses
		private bool[] m_AnswerUsesRichFormatting;
		public bool[] AnswerUsesRichFormatting {
			get { return m_AnswerUsesRichFormatting; }
			set { m_AnswerUsesRichFormatting = value; }
		}
		
		private string m_Remarks;
		public string Remarks {
			get { return m_Remarks; }
			set { m_Remarks = value; }
		}
		
		//N.B.: not yet used in any version, but is included for future uses
		private bool[] m_RemarkUsesRichFormatting;		
		public bool[] RemarkUsesRichFormatting {
			get { return m_RemarkUsesRichFormatting; }
			set { m_RemarkUsesRichFormatting = value; }
		}


		#endregion

		
		#region Dynamic fields (set by Exam-object!)
		
		private QuestionDirection m_QuestionDirection;
		public QuestionDirection QuestionDirection {
			get { return m_QuestionDirection; }
			set { m_QuestionDirection = value; }
		}
		
		private ExamCheck m_ExamCheck;
		public ExamCheck ExamCheck {
			get { return m_ExamCheck; }
			set { m_ExamCheck = value; }
		}
		
		#endregion

		
		public abstract bool IsAnswerCorrect(string inputText);		//Normal
		public abstract bool IsAnswerCorrect(bool[] tickedBoxes);	//Multiplechoice
		
	}
}
