/*
 * Copyright 2008, by Danil S. Trommel, Avance, The Netherlands
 * 
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

using System.Windows.Forms;
using System;
using System.Runtime.InteropServices;


namespace miniTeach.Tools
{
	/// <summary>
	/// Description of SIPTool.
	/// </summary>
	public static class SIPTool
	{

		private static int m_dwSipFlasg;

		
		public static void DisableCompletion(TextBox textBox)
		{
			textBox.Capture = true;
			IntPtr m_hWnd = GetCapture();
			textBox.Capture = false;
			SIPINFO info = new SIPINFO();
			SHSipInfo(SPI_GETSIPINFO, 0, info, 0);
			m_dwSipFlasg = info.fdwFlags;
			info.fdwFlags = info.fdwFlags | SIPF_DISABLECOMPLETION;
			SHSipInfo(SPI_SETSIPINFO, 0, info, 0);
			SHSipPreference(m_hWnd, SIPSTATE.SIP_FORCEDOWN);
			SHSipPreference(m_hWnd, SIPSTATE.SIP_UP);
		}


		public static void EnableCompletion(TextBox textBox)
		{
			textBox.Capture = true;
			IntPtr m_hWnd = GetCapture();
			textBox.Capture = false;
			SIPINFO info = new SIPINFO();
			SHSipInfo(SPI_GETSIPINFO, 0, info, 0);
			info.fdwFlags = m_dwSipFlasg;
			SHSipInfo(SPI_SETSIPINFO, 0, info, 0);
			SHSipPreference(m_hWnd, SIPSTATE.SIP_FORCEDOWN);
			SHSipPreference(m_hWnd, SIPSTATE.SIP_UP);
		}
		

		#region "p/invoke"

		private const int SPI_SETSIPINFO = 224;
		private const int SPI_GETSIPINFO = 225;
		private const int SIPF_DISABLECOMPLETION = 8;


		[DllImport("coredll")] static extern IntPtr GetCapture();
		[DllImport("aygshell")] static extern int SHSipInfo(uint uiAction, uint uiParam, SIPINFO pvParam, uint fWinIni);
		[DllImport("aygshell")] static extern int SHSipPreference(IntPtr hwnd, SIPSTATE st);
		

		[StructLayout(LayoutKind.Sequential, CharSet = CharSet.Auto)]
		private struct SIPINFO
		{
			public int cbSize;
			public int fdwFlags;
			//RECT    rcVisibleDesktop;
			public int deskLeft;
			public int deskTop;
			public int deskRight;
			public int deskBottom;
			//RECT    rcSipRect;
			public int sipLeft;
			public int sipTop;
			public int sipRight;
			public int sipBottom;
			public int dwImDataSize;
			public IntPtr pvImData;
		}

		
		private enum SIPSTATE
		{
			SIP_UP = 0,
			SIP_DOWN,
			SIP_FORCEDOWN,
			SIP_UNCHANGED,
			SIP_INPUTDIALOG
		}
		

		#endregion
		

	}
}
