/*
 * Copyright 2008, by Danil S. Trommel, Avance, The Netherlands
 * 
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/



using System;

namespace miniTeach.Tools
{
	/// <summary>
	/// Description of TeachTools.
	/// </summary>
	public static class TeachTools
	{

		/// <summary>
		/// Test whether an array of strings, with possible rich text tags, contains a certain string
		/// </summary>
		/// <param name="testText">The string that will be searched in the correctText array</param>
		/// <param name="correctText">Array with correct possible text</param>
		/// <param name="richFormatted">Boolean values corresponding to items in the correctText array</param>
		/// <returns></returns>
		public static bool ArrayContainsString(string testText, string[] correctTextArray, bool[] usesRichFormat, bool IgnoreCasing)
		{
			for(int index = 0; index < correctTextArray.Length; index++)
			{
				bool correct = IsIdenticalText(testText, correctTextArray[index], usesRichFormat[index], IgnoreCasing);
				if (correct)
				{
					return true;
				}
			}
			
			return false;	//not found!
		}
		
		private static bool IsIdenticalText(string testText, string correctText, bool usesRichFormat, bool IgnoreCasing)
		{
			if (usesRichFormat)
			{
				correctText = RichTools.StripRichTags(correctText);
			}

			if (IgnoreCasing)
			{
				correctText = correctText.ToLower();
				testText = testText.ToLower();
			}
			
			return (testText == correctText);
		}
	}
}
