/*
 * Copyright 2008, by Danil S. Trommel, Avance, The Netherlands
 * 
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

using System;
using System.Drawing;

using miniTeach.Teach;
using miniTeach.Tools;
using miniTeach.Settings;


//TODO: add word-wrapping functionality; cut string before
//		the last word that exceeds the screens width.

namespace miniTeach.UI
{
	/// <summary>
	/// Description of TeachPictureBox.
	/// </summary>
	public partial class TeachPictureBox : LightWeightPictureBox
	{
		
		
		private void DrawQuestionNormal()
		{
			if (m_CurrentQuestion.QuestionDirection == QuestionDirection.Foreign)
			{
				DrawNormal(m_CurrentQuestion.Questions, m_CurrentQuestion.QuestionUsesRichFormatting);
			}
			else
			{
				DrawNormal(m_CurrentQuestion.Answers, m_CurrentQuestion.AnswerUsesRichFormatting);
			}
		}
		
		private void DrawAnswerNormal()
		{
			if (m_CurrentQuestion.QuestionDirection == QuestionDirection.Foreign)
			{
				DrawNormal(m_CurrentQuestion.Answers, m_CurrentQuestion.AnswerUsesRichFormatting);
			}
			else
			{
				DrawNormal(m_CurrentQuestion.Questions, m_CurrentQuestion.QuestionUsesRichFormatting);
			}
		}
		
		
		private void DrawNormal(string[] displayItems, bool[] isRichFormatted)
		{
			//Init offsets used to correctly offset lines etc.
			this.m_TextOffset = TeachSettings.TextOffset;
			float offsetX = this.m_TextOffset;
			float offsetY = TeachSettings.TextOffset;
			
			//Prepare text for measuring the required space
			string measureText = PrepareMeasureString(displayItems);
			//Append any remarks
			if ( !String.IsNullOrEmpty(m_CurrentQuestion.Remarks) )
			{
				measureText += "\r\n" + RemarkSeparator + "\r\n" + m_CurrentQuestion.Remarks;
			}
			
			//Init bitmap, correctly sized to house the text
			InitCorrectlySizedBitmap(measureText, (int)offsetX, (int)offsetY);
			
			//Draw
			DrawNormal(displayItems, isRichFormatted, ref offsetX, ref offsetY);
			
			//Draw remarks
			if ( !String.IsNullOrEmpty(m_CurrentQuestion.Remarks) )
			{
				//TODO: create a more elegant solution with a separate function?
				DrawNormal(new string[]{RemarkSeparator, m_CurrentQuestion.Remarks}, 
				           new bool[]{false, false}, ref offsetX, ref offsetY);
			}
						
			Invalidate();	//force the control to update
		}
		
		private void DrawNormal(string[] displayItems, bool[] isRichFormatted, 
		                        ref float offsetX, ref float offsetY)
		{
			Graphics graphics = Graphics.FromImage(image);	//Init graphics
			
			//Draw items
			for (int index = 0; index < displayItems.Length; index++)
			{
				DrawItem(displayItems[index], isRichFormatted[index],
				         ref graphics, ref offsetX, ref offsetY);
			}
						
			graphics.Dispose();	//clean up
		}
		
		private void CheckAnswerNormal(string inputText)
		{
			m_QuestionCorrectlyAnswered = m_CurrentQuestion.IsAnswerCorrect(inputText);
		}
		
	}
}
